@@ -6,10 +6,11 @@ Type annotations for databrew service client.
 Usage::
 
     ```python
-    import boto3
-    from mypy_boto3_databrew import GlueDataBrewClient
+    from boto3.session import Session
+    from mypy_boto3_databrew.client import GlueDataBrewClient
 
-    client: GlueDataBrewClient = boto3.client("databrew")
+    session = Session()
+    client: GlueDataBrewClient = session.client("databrew")
     ```
 """
 import sys
@@ -117,7 +118,7 @@ class Exceptions:
 
 class GlueDataBrewClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.32/reference/services/databrew.html#GlueDataBrew.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/databrew.html#GlueDataBrew.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html)
     """
 
@@ -127,6 +128,9 @@ class GlueDataBrewClient(BaseClient):
     def exceptions(self) -> Exceptions:
         """
         GlueDataBrewClient exceptions.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/databrew.html#GlueDataBrew.Client.exceptions)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#exceptions)
         """
 
     def batch_delete_recipe_version(
@@ -135,7 +139,7 @@ class GlueDataBrewClient(BaseClient):
         """
         Deletes one or more versions of a recipe at a time.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.32/reference/services/databrew.html#GlueDataBrew.Client.batch_delete_recipe_version)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/databrew.html#GlueDataBrew.Client.batch_delete_recipe_version)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#batch_delete_recipe_version)
         """
 
@@ -143,7 +147,7 @@ class GlueDataBrewClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.32/reference/services/databrew.html#GlueDataBrew.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/databrew.html#GlueDataBrew.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#can_paginate)
         """
 
@@ -160,7 +164,7 @@ class GlueDataBrewClient(BaseClient):
         """
         Creates a new DataBrew dataset.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.32/reference/services/databrew.html#GlueDataBrew.Client.create_dataset)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/databrew.html#GlueDataBrew.Client.create_dataset)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#create_dataset)
         """
 
@@ -185,7 +189,7 @@ class GlueDataBrewClient(BaseClient):
         """
         Creates a new job to analyze a dataset and create its data profile.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.32/reference/services/databrew.html#GlueDataBrew.Client.create_profile_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/databrew.html#GlueDataBrew.Client.create_profile_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#create_profile_job)
         """
 
@@ -202,7 +206,7 @@ class GlueDataBrewClient(BaseClient):
         """
         Creates a new DataBrew project.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.32/reference/services/databrew.html#GlueDataBrew.Client.create_project)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/databrew.html#GlueDataBrew.Client.create_project)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#create_project)
         """
 
@@ -217,7 +221,7 @@ class GlueDataBrewClient(BaseClient):
         """
         Creates a new DataBrew recipe.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.32/reference/services/databrew.html#GlueDataBrew.Client.create_recipe)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/databrew.html#GlueDataBrew.Client.create_recipe)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#create_recipe)
         """
 
@@ -242,11 +246,10 @@ class GlueDataBrewClient(BaseClient):
     ) -> CreateRecipeJobResponseTypeDef:
         """
         Creates a new job to transform input data, using steps defined in an existing
-        Glue DataBrew recipe See also: `AWS API Documentation
-        <https://docs.aws.amazon.com/goto/WebAPI/databrew-2017-07-25/CreateRecipeJob>`_
-        **Request Syntax** response = client.create_recipe_job( DatasetName...
+        Glue DataBrew recipe See also: [AWS API
+        Documentation](https://docs.aws.amazon.com/goto/WebAPI/databrew-2017-07-25/CreateRecipeJob).
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.32/reference/services/databrew.html#GlueDataBrew.Client.create_recipe_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/databrew.html#GlueDataBrew.Client.create_recipe_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#create_recipe_job)
         """
 
@@ -263,7 +266,7 @@ class GlueDataBrewClient(BaseClient):
         Creates a new ruleset that can be used in a profile job to validate the data
         quality of a dataset.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.32/reference/services/databrew.html#GlueDataBrew.Client.create_ruleset)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/databrew.html#GlueDataBrew.Client.create_ruleset)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#create_ruleset)
         """
 
@@ -278,7 +281,7 @@ class GlueDataBrewClient(BaseClient):
         """
         Creates a new schedule for one or more DataBrew jobs.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.32/reference/services/databrew.html#GlueDataBrew.Client.create_schedule)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/databrew.html#GlueDataBrew.Client.create_schedule)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#create_schedule)
         """
 
@@ -286,7 +289,7 @@ class GlueDataBrewClient(BaseClient):
         """
         Deletes a dataset from DataBrew.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.32/reference/services/databrew.html#GlueDataBrew.Client.delete_dataset)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/databrew.html#GlueDataBrew.Client.delete_dataset)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#delete_dataset)
         """
 
@@ -294,7 +297,7 @@ class GlueDataBrewClient(BaseClient):
         """
         Deletes the specified DataBrew job.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.32/reference/services/databrew.html#GlueDataBrew.Client.delete_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/databrew.html#GlueDataBrew.Client.delete_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#delete_job)
         """
 
@@ -302,7 +305,7 @@ class GlueDataBrewClient(BaseClient):
         """
         Deletes an existing DataBrew project.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.32/reference/services/databrew.html#GlueDataBrew.Client.delete_project)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/databrew.html#GlueDataBrew.Client.delete_project)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#delete_project)
         """
 
@@ -312,7 +315,7 @@ class GlueDataBrewClient(BaseClient):
         """
         Deletes a single version of a DataBrew recipe.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.32/reference/services/databrew.html#GlueDataBrew.Client.delete_recipe_version)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/databrew.html#GlueDataBrew.Client.delete_recipe_version)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#delete_recipe_version)
         """
 
@@ -320,7 +323,7 @@ class GlueDataBrewClient(BaseClient):
         """
         Deletes a ruleset.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.32/reference/services/databrew.html#GlueDataBrew.Client.delete_ruleset)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/databrew.html#GlueDataBrew.Client.delete_ruleset)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#delete_ruleset)
         """
 
@@ -328,7 +331,7 @@ class GlueDataBrewClient(BaseClient):
         """
         Deletes the specified DataBrew schedule.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.32/reference/services/databrew.html#GlueDataBrew.Client.delete_schedule)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/databrew.html#GlueDataBrew.Client.delete_schedule)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#delete_schedule)
         """
 
@@ -336,7 +339,7 @@ class GlueDataBrewClient(BaseClient):
         """
         Returns the definition of a specific DataBrew dataset.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.32/reference/services/databrew.html#GlueDataBrew.Client.describe_dataset)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/databrew.html#GlueDataBrew.Client.describe_dataset)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#describe_dataset)
         """
 
@@ -344,7 +347,7 @@ class GlueDataBrewClient(BaseClient):
         """
         Returns the definition of a specific DataBrew job.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.32/reference/services/databrew.html#GlueDataBrew.Client.describe_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/databrew.html#GlueDataBrew.Client.describe_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#describe_job)
         """
 
@@ -352,7 +355,7 @@ class GlueDataBrewClient(BaseClient):
         """
         Represents one run of a DataBrew job.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.32/reference/services/databrew.html#GlueDataBrew.Client.describe_job_run)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/databrew.html#GlueDataBrew.Client.describe_job_run)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#describe_job_run)
         """
 
@@ -360,7 +363,7 @@ class GlueDataBrewClient(BaseClient):
         """
         Returns the definition of a specific DataBrew project.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.32/reference/services/databrew.html#GlueDataBrew.Client.describe_project)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/databrew.html#GlueDataBrew.Client.describe_project)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#describe_project)
         """
 
@@ -371,7 +374,7 @@ class GlueDataBrewClient(BaseClient):
         Returns the definition of a specific DataBrew recipe corresponding to a
         particular version.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.32/reference/services/databrew.html#GlueDataBrew.Client.describe_recipe)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/databrew.html#GlueDataBrew.Client.describe_recipe)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#describe_recipe)
         """
 
@@ -379,7 +382,7 @@ class GlueDataBrewClient(BaseClient):
         """
         Retrieves detailed information about the ruleset.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.32/reference/services/databrew.html#GlueDataBrew.Client.describe_ruleset)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/databrew.html#GlueDataBrew.Client.describe_ruleset)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#describe_ruleset)
         """
 
@@ -387,7 +390,7 @@ class GlueDataBrewClient(BaseClient):
         """
         Returns the definition of a specific DataBrew schedule.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.32/reference/services/databrew.html#GlueDataBrew.Client.describe_schedule)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/databrew.html#GlueDataBrew.Client.describe_schedule)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#describe_schedule)
         """
 
@@ -401,7 +404,7 @@ class GlueDataBrewClient(BaseClient):
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.32/reference/services/databrew.html#GlueDataBrew.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/databrew.html#GlueDataBrew.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#generate_presigned_url)
         """
 
@@ -411,7 +414,7 @@ class GlueDataBrewClient(BaseClient):
         """
         Lists all of the DataBrew datasets.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.32/reference/services/databrew.html#GlueDataBrew.Client.list_datasets)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/databrew.html#GlueDataBrew.Client.list_datasets)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#list_datasets)
         """
 
@@ -421,7 +424,7 @@ class GlueDataBrewClient(BaseClient):
         """
         Lists all of the previous runs of a particular DataBrew job.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.32/reference/services/databrew.html#GlueDataBrew.Client.list_job_runs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/databrew.html#GlueDataBrew.Client.list_job_runs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#list_job_runs)
         """
 
@@ -436,7 +439,7 @@ class GlueDataBrewClient(BaseClient):
         """
         Lists all of the DataBrew jobs that are defined.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.32/reference/services/databrew.html#GlueDataBrew.Client.list_jobs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/databrew.html#GlueDataBrew.Client.list_jobs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#list_jobs)
         """
 
@@ -446,7 +449,7 @@ class GlueDataBrewClient(BaseClient):
         """
         Lists all of the DataBrew projects that are defined.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.32/reference/services/databrew.html#GlueDataBrew.Client.list_projects)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/databrew.html#GlueDataBrew.Client.list_projects)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#list_projects)
         """
 
@@ -457,7 +460,7 @@ class GlueDataBrewClient(BaseClient):
         Lists the versions of a particular DataBrew recipe, except for `LATEST_WORKING`
         .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.32/reference/services/databrew.html#GlueDataBrew.Client.list_recipe_versions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/databrew.html#GlueDataBrew.Client.list_recipe_versions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#list_recipe_versions)
         """
 
@@ -467,7 +470,7 @@ class GlueDataBrewClient(BaseClient):
         """
         Lists all of the DataBrew recipes that are defined.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.32/reference/services/databrew.html#GlueDataBrew.Client.list_recipes)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/databrew.html#GlueDataBrew.Client.list_recipes)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#list_recipes)
         """
 
@@ -478,7 +481,7 @@ class GlueDataBrewClient(BaseClient):
         List all rulesets available in the current account or rulesets associated with a
         specific resource (dataset).
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.32/reference/services/databrew.html#GlueDataBrew.Client.list_rulesets)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/databrew.html#GlueDataBrew.Client.list_rulesets)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#list_rulesets)
         """
 
@@ -488,7 +491,7 @@ class GlueDataBrewClient(BaseClient):
         """
         Lists the DataBrew schedules that are defined.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.32/reference/services/databrew.html#GlueDataBrew.Client.list_schedules)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/databrew.html#GlueDataBrew.Client.list_schedules)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#list_schedules)
         """
 
@@ -496,7 +499,7 @@ class GlueDataBrewClient(BaseClient):
         """
         Lists all the tags for a DataBrew resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.32/reference/services/databrew.html#GlueDataBrew.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/databrew.html#GlueDataBrew.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#list_tags_for_resource)
         """
 
@@ -504,7 +507,7 @@ class GlueDataBrewClient(BaseClient):
         """
         Publishes a new version of a DataBrew recipe.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.32/reference/services/databrew.html#GlueDataBrew.Client.publish_recipe)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/databrew.html#GlueDataBrew.Client.publish_recipe)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#publish_recipe)
         """
 
@@ -522,7 +525,7 @@ class GlueDataBrewClient(BaseClient):
         Performs a recipe step within an interactive DataBrew session that's currently
         open.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.32/reference/services/databrew.html#GlueDataBrew.Client.send_project_session_action)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/databrew.html#GlueDataBrew.Client.send_project_session_action)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#send_project_session_action)
         """
 
@@ -530,7 +533,7 @@ class GlueDataBrewClient(BaseClient):
         """
         Runs a DataBrew job.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.32/reference/services/databrew.html#GlueDataBrew.Client.start_job_run)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/databrew.html#GlueDataBrew.Client.start_job_run)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#start_job_run)
         """
 
@@ -541,7 +544,7 @@ class GlueDataBrewClient(BaseClient):
         Creates an interactive session, enabling you to manipulate data in a DataBrew
         project.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.32/reference/services/databrew.html#GlueDataBrew.Client.start_project_session)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/databrew.html#GlueDataBrew.Client.start_project_session)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#start_project_session)
         """
 
@@ -549,7 +552,7 @@ class GlueDataBrewClient(BaseClient):
         """
         Stops a particular run of a job.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.32/reference/services/databrew.html#GlueDataBrew.Client.stop_job_run)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/databrew.html#GlueDataBrew.Client.stop_job_run)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#stop_job_run)
         """
 
@@ -558,7 +561,7 @@ class GlueDataBrewClient(BaseClient):
         Adds metadata tags to a DataBrew resource, such as a dataset, project, recipe,
         job, or schedule.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.32/reference/services/databrew.html#GlueDataBrew.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/databrew.html#GlueDataBrew.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#tag_resource)
         """
 
@@ -566,7 +569,7 @@ class GlueDataBrewClient(BaseClient):
         """
         Removes metadata tags from a DataBrew resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.32/reference/services/databrew.html#GlueDataBrew.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/databrew.html#GlueDataBrew.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#untag_resource)
         """
 
@@ -582,7 +585,7 @@ class GlueDataBrewClient(BaseClient):
         """
         Modifies the definition of an existing DataBrew dataset.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.32/reference/services/databrew.html#GlueDataBrew.Client.update_dataset)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/databrew.html#GlueDataBrew.Client.update_dataset)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#update_dataset)
         """
 
@@ -605,7 +608,7 @@ class GlueDataBrewClient(BaseClient):
         """
         Modifies the definition of an existing profile job.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.32/reference/services/databrew.html#GlueDataBrew.Client.update_profile_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/databrew.html#GlueDataBrew.Client.update_profile_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#update_profile_job)
         """
 
@@ -615,7 +618,7 @@ class GlueDataBrewClient(BaseClient):
         """
         Modifies the definition of an existing DataBrew project.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.32/reference/services/databrew.html#GlueDataBrew.Client.update_project)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/databrew.html#GlueDataBrew.Client.update_project)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#update_project)
         """
 
@@ -625,7 +628,7 @@ class GlueDataBrewClient(BaseClient):
         """
         Modifies the definition of the `LATEST_WORKING` version of a DataBrew recipe.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.32/reference/services/databrew.html#GlueDataBrew.Client.update_recipe)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/databrew.html#GlueDataBrew.Client.update_recipe)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#update_recipe)
         """
 
@@ -647,7 +650,7 @@ class GlueDataBrewClient(BaseClient):
         """
         Modifies the definition of an existing DataBrew recipe job.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.32/reference/services/databrew.html#GlueDataBrew.Client.update_recipe_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/databrew.html#GlueDataBrew.Client.update_recipe_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#update_recipe_job)
         """
 
@@ -657,7 +660,7 @@ class GlueDataBrewClient(BaseClient):
         """
         Updates specified ruleset.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.32/reference/services/databrew.html#GlueDataBrew.Client.update_ruleset)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/databrew.html#GlueDataBrew.Client.update_ruleset)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#update_ruleset)
         """
 
@@ -667,36 +670,36 @@ class GlueDataBrewClient(BaseClient):
         """
         Modifies the definition of an existing DataBrew schedule.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.32/reference/services/databrew.html#GlueDataBrew.Client.update_schedule)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/databrew.html#GlueDataBrew.Client.update_schedule)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#update_schedule)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_datasets"]) -> ListDatasetsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.32/reference/services/databrew.html#GlueDataBrew.Paginator.ListDatasets)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/paginators.html#listdatasetspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/databrew.html#GlueDataBrew.Client.get_paginator)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#get_paginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_job_runs"]) -> ListJobRunsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.32/reference/services/databrew.html#GlueDataBrew.Paginator.ListJobRuns)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/paginators.html#listjobrunspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/databrew.html#GlueDataBrew.Client.get_paginator)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#get_paginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_jobs"]) -> ListJobsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.32/reference/services/databrew.html#GlueDataBrew.Paginator.ListJobs)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/paginators.html#listjobspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/databrew.html#GlueDataBrew.Client.get_paginator)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#get_paginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_projects"]) -> ListProjectsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.32/reference/services/databrew.html#GlueDataBrew.Paginator.ListProjects)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/paginators.html#listprojectspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/databrew.html#GlueDataBrew.Client.get_paginator)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#get_paginator)
         """
 
     @overload
@@ -704,27 +707,27 @@ class GlueDataBrewClient(BaseClient):
         self, operation_name: Literal["list_recipe_versions"]
     ) -> ListRecipeVersionsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.32/reference/services/databrew.html#GlueDataBrew.Paginator.ListRecipeVersions)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/paginators.html#listrecipeversionspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/databrew.html#GlueDataBrew.Client.get_paginator)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#get_paginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_recipes"]) -> ListRecipesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.32/reference/services/databrew.html#GlueDataBrew.Paginator.ListRecipes)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/paginators.html#listrecipespaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/databrew.html#GlueDataBrew.Client.get_paginator)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#get_paginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_rulesets"]) -> ListRulesetsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.32/reference/services/databrew.html#GlueDataBrew.Paginator.ListRulesets)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/paginators.html#listrulesetspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/databrew.html#GlueDataBrew.Client.get_paginator)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#get_paginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_schedules"]) -> ListSchedulesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.32/reference/services/databrew.html#GlueDataBrew.Paginator.ListSchedules)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/paginators.html#listschedulespaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/databrew.html#GlueDataBrew.Client.get_paginator)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#get_paginator)
         """
