@@ -107,6 +107,7 @@ ServiceName = Literal[
     "amp",
     "amplify",
     "amplifybackend",
+    "amplifyuibuilder",
     "apigateway",
     "apigatewaymanagementapi",
     "apigatewayv2",
@@ -126,6 +127,7 @@ ServiceName = Literal[
     "autoscaling",
     "autoscaling-plans",
     "backup",
+    "backup-gateway",
     "batch",
     "braket",
     "budgets",
@@ -202,6 +204,7 @@ ServiceName = Literal[
     "emr-containers",
     "es",
     "events",
+    "evidently",
     "finspace",
     "finspace-data",
     "firehose",
@@ -228,6 +231,7 @@ ServiceName = Literal[
     "imagebuilder",
     "importexport",
     "inspector",
+    "inspector2",
     "iot",
     "iot-data",
     "iot-jobs-data",
@@ -241,6 +245,7 @@ ServiceName = Literal[
     "iotsecuretunneling",
     "iotsitewise",
     "iotthingsgraph",
+    "iottwinmaker",
     "iotwireless",
     "ivs",
     "kafka",
@@ -286,6 +291,7 @@ ServiceName = Literal[
     "meteringmarketplace",
     "mgh",
     "mgn",
+    "migration-hub-refactor-spaces",
     "migrationhub-config",
     "migrationhubstrategy",
     "mobile",
@@ -316,6 +322,7 @@ ServiceName = Literal[
     "qldb-session",
     "quicksight",
     "ram",
+    "rbin",
     "rds",
     "rds-data",
     "redshift",
@@ -331,6 +338,7 @@ ServiceName = Literal[
     "route53-recovery-readiness",
     "route53domains",
     "route53resolver",
+    "rum",
     "s3",
     "s3control",
     "s3outposts",
@@ -388,6 +396,7 @@ ServiceName = Literal[
     "workmail",
     "workmailmessageflow",
     "workspaces",
+    "workspaces-web",
     "xray",
 ]
 PaginatorName = Literal[
